# SzEngineDeleteRecordResponse

{
"AFFECTED_ENTITIES": [
{
"ENTITY_ID": "int32"
}
],
"DATA_SOURCE": "string",
"RECORD_ID": "string",
"XXX_INTERESTING_ENTITIES": {
"ENTITIES": [
{
"DEGREES": "int32",
"ENTITY_ID": "int32",
"FLAGS": [
"string"
],
"SAMPLE_RECORDS": [
{
"DATA_SOURCE": "string",
"FLAGS": [
"string"
],
"RECORD_ID": "string"
}
]
}
],
"NOTICES": [
{
"CODE": "string",
"DESCRIPTION": "string"
}
]
}
}